package com.atlassian.crucible.plugin.export;

import java.util.List;

import com.atlassian.crucible.spi.PermId;
import com.atlassian.crucible.spi.data.FisheyeReviewItemData;
import com.atlassian.crucible.spi.data.GeneralCommentData;
import com.atlassian.crucible.spi.data.ReviewData;
import com.atlassian.crucible.spi.data.ReviewItemData;
import com.atlassian.crucible.spi.data.VersionedLineCommentData;
import com.atlassian.crucible.spi.impl.Utils;
import com.atlassian.crucible.spi.rpc.RpcAuthHelper;
import com.atlassian.crucible.spi.services.ReviewService;
import com.cenqua.crucible.model.CrucibleUser;
import com.cenqua.fisheye.config.SpringContext;

/**
 * Provides direct interaction with the Crucible API directly, through the
 * {@link ReviewService} instance.
 * 
 * @author Ross Rowe
 * 
 */
public class CrucibleDirectClient implements CrucibleClient {

	private ReviewService reviewService;

	public CrucibleDirectClient(ReviewService reviewService) {
		this.reviewService = reviewService;
	}

	/**
	 * Returns the list of {@link GeneralCommentData} instances for the
	 * reviewId.
	 */
	public List<GeneralCommentData> getGeneralComments(String reviewId) {
		return reviewService
				.getGeneralComments(new PermId<ReviewData>(reviewId));
	}

	/**
	 * Retrieves the {@link ReviewData} instance for the reviewId.
	 */
	public ReviewData getReview(String reviewId) {
		return reviewService.getReview(new PermId<ReviewData>(reviewId));
	}

	/**
	 * Returns a list of {@link VersionedLineCommentData} instances for the
	 * reviewId.
	 */
	public List<VersionedLineCommentData> getVersionedComments(String reviewId) {
		return reviewService.getVersionedComments(new PermId<ReviewItemData>(
				reviewId));
	}

	/**
	 * Performs a login action using the username and password.
	 * 
	 */
	public String login(String username, String password) {

		RpcAuthHelper authHelper = (RpcAuthHelper) SpringContext
				.getComponent("rpcAuthHelper");
		return authHelper.login(username, password, "");
	}

	/**
	 * Retrieves the {@link FisheyeReviewItemData} instance for the reviewId and
	 * the reviewItemId.
	 */
	public FisheyeReviewItemData getReviewItemData(String reviewId,
			String reviewItemId) {
		return reviewService.getReviewItem(new PermId<ReviewData>(reviewId),
				new PermId<ReviewItemData>(reviewItemId));
	}

	/**
	 * Returns a user's real name.
	 */
	public String getUserName(String userId) {
		CrucibleUser user = Utils.getUserByName(userId);
		return user.getUserName();
	}

}
